package cn.cecep.talroad.service;

import cn.cecep.talroad.vo.*;
import cn.cecep.talroad.vo.homepage.HpmEnvironmentOverviewVo;
import cn.cecep.talroad.vo.homepage.HpmMeriRatingOverviewVo;

import java.util.List;
import java.util.Map;

/**
 * @author changyw
 * @date 2023/2/22
 */
public interface KeyEmittingIndustryService {
    IndustryCompanyOverviewVo selectIndustryCompanyOverview(String industry, String regionCode);

    HpmMeriRatingOverviewVo selectMeritRatingOverview(String industry,String regionCode);

    HpmEnvironmentOverviewVo selectOnvironmentOverview(String industry,String regionCode);

    List<IndustryEmissionTrackingOverviewVo> selectIndustryEmissionTrackingOverviewVo(String emissionType, String industry, String regionCode);

    List<IndustrialHazardousWasteVo> selectProductionAndDisposalOfIndustrialHazardousWaste(String industry, String regionCode);

    EChartsVO selectIndustryPollutantDischargeTrends(String pollutantCategory, String industry, String regionCode);

    EChartsVO selectIndustryProductOutputTrends(String industry, String regionCode);

    List<IndustryPollutantEmissionsTop10Vo> selectTop10CompaniesWithPollutantEmissionsInTheIndustry(String pollutantType, String industry, String regionCode);

    EChartsVO selectLawEnforcementStatistics(String industry);

    EChartsVO selectIndustryPollutantTreatmentProcess(String industry);

    List<LawEnforcementPieStatisticsVo> selectLawEnforcementPieStatistics(Map map);

}
